
import React from 'react';
import { Link } from 'react-router-dom';
import { CheckCircle, Clock, Star, Play, ArrowDown, Shield, TrendingUp, Users } from 'lucide-react';
import { Button } from './ui/button';

const Hero = () => {
  return (
    <section className="relative bg-gradient-to-br from-road-blue via-blue-600 to-blue-800 text-white overflow-hidden min-h-screen flex items-center">
      {/* Background Pattern */}
      <div className="absolute inset-0 bg-black bg-opacity-20">
        <div className="absolute inset-0" style={{
          backgroundImage: `url("data:image/svg+xml,%3Csvg width='60' height='60' viewBox='0 0 60 60' xmlns='http://www.w3.org/2000/svg'%3E%3Cg fill='%23ffffff' fill-opacity='0.03'%3E%3Cpath d='M30 30c0-16.569-13.431-30-30-30v30h30z'/%3E%3C/g%3E%3C/svg%3E")`,
        }} />
      </div>

      {/* Éléments décoratifs */}
      <div className="absolute top-20 left-10 w-20 h-20 bg-road-yellow rounded-full opacity-20 animate-float" />
      <div className="absolute top-40 right-20 w-16 h-16 bg-road-red rounded-full opacity-20 animate-float" style={{ animationDelay: '1s' }} />
      <div className="absolute bottom-32 left-20 w-12 h-12 bg-road-green rounded-full opacity-20 animate-float" style={{ animationDelay: '2s' }} />

      <div className="relative max-w-7xl mx-auto px-4 sm:px-6 lg:px-8 py-20">
        <div className="grid lg:grid-cols-2 gap-16 items-center">
          {/* Contenu optimisé avec headline orienté bénéfice */}
          <div className="space-y-8 animate-fade-in">
            {/* Preuve sociale immédiate */}
            <div className="inline-flex items-center bg-green-600 text-white px-6 py-3 rounded-full text-sm font-bold shadow-lg">
              <Users className="w-4 h-4 mr-2" />
              Rejoignez 12 000+ élèves qui ont réussi !
            </div>

            {/* Headline orienté bénéfice */}
            <h1 className="text-5xl lg:text-7xl font-extrabold leading-tight">
              Réussissez votre{' '}
              <span className="bg-gradient-to-r from-road-yellow to-yellow-300 bg-clip-text text-transparent">
                code de la route
              </span>{' '}
              en 8 jours chrono
            </h1>

            {/* Sous-titre avec proposition de valeur claire */}
            <div className="space-y-4">
              <p className="text-xl lg:text-2xl text-blue-100 leading-relaxed font-light">
                La <strong className="text-white font-semibold">méthode progressive #1</strong> pour décrocher votre code du premier coup, 
                même si vous partez de zéro.
              </p>
              <div className="bg-green-600/20 border border-green-400 rounded-lg p-4">
                <p className="text-lg text-white flex items-center">
                  <CheckCircle className="w-5 h-5 mr-2 text-green-400" />
                  <strong>Garantie réussite</strong> : 94% de nos élèves obtiennent leur code
                </p>
              </div>
            </div>

            {/* Bénéfices structurés avec points forts */}
            <div className="grid sm:grid-cols-2 gap-4">
              {[
                { text: '8 jours de formation', icon: '📅', benefit: 'Méthode progressive' },
                { text: '150+ quiz interactifs', icon: '🧠', benefit: 'Entraînement intensif' },
                { text: 'Support 7j/7', icon: '💬', benefit: 'Assistance permanente' },
                { text: 'Accès à vie', icon: '♾️', benefit: 'Révisions illimitées' }
              ].map((point, index) => (
                <div 
                  key={index} 
                  className="flex items-center space-x-3 animate-fade-in hover:scale-105 transition-transform bg-white/10 rounded-lg p-4 backdrop-blur-sm"
                  style={{ animationDelay: `${index * 0.1}s` }}
                >
                  <span className="text-2xl">{point.icon}</span>
                  <div>
                    <div className="text-white font-semibold">{point.text}</div>
                    <div className="text-blue-200 text-sm">{point.benefit}</div>
                  </div>
                </div>
              ))}
            </div>

            {/* Preuve sociale avec témoignage */}
            <div className="bg-white/10 border border-blue-400 rounded-lg p-6 backdrop-blur-sm">
              <div className="flex items-start space-x-4">
                <div className="flex-shrink-0">
                  <div className="w-12 h-12 bg-gradient-to-r from-green-400 to-green-600 rounded-full flex items-center justify-center text-white font-bold text-lg">
                    M
                  </div>
                </div>
                <div>
                  <p className="text-white italic mb-2">
                    "Grâce à cette méthode, j'ai eu mon code en 8 jours exactement ! 
                    Les fiches sont super claires et les quiz m'ont vraiment préparé."
                  </p>
                  <div className="flex items-center space-x-2">
                    <span className="text-blue-200 font-medium">Marie L., 19 ans</span>
                    <div className="flex">
                      {[...Array(5)].map((_, i) => (
                        <Star key={i} className="w-4 h-4 text-yellow-400 fill-current" />
                      ))}
                    </div>
                  </div>
                </div>
              </div>
            </div>

            {/* CTA avec urgence sociale */}
            <div className="space-y-4">
              <div className="flex flex-col sm:flex-row gap-4 pt-4">
                <Link to="/catalogue">
                  <Button 
                    size="lg" 
                    className="bg-gradient-to-r from-road-yellow to-yellow-400 text-black hover:from-yellow-400 hover:to-yellow-500 font-bold px-10 py-4 text-lg shadow-xl hover:scale-105 transition-all duration-300 border-0"
                  >
                    🚀 Commencer ma formation
                  </Button>
                </Link>
                <Link to="/quiz">
                  <Button 
                    variant="outline" 
                    size="lg"
                    className="border-2 border-white text-white hover:bg-white hover:text-road-blue font-bold px-10 py-4 text-lg backdrop-blur-sm bg-white/10 hover:scale-105 transition-all duration-300"
                  >
                    <Play className="w-5 h-5 mr-2" />
                    Quiz gratuit
                  </Button>
                </Link>
              </div>
              <p className="text-blue-200 text-sm text-center">
                ⏰ <strong>127 personnes</strong> se sont inscrites aujourd'hui
              </p>
            </div>

            {/* Stats avec preuves sociales */}
            <div className="flex items-center justify-between pt-8 border-t border-blue-400/30">
              {[
                { value: '12 000+', label: 'Élèves formés', icon: '👥' },
                { value: '94%', label: 'Taux de réussite', icon: '🎯' },
                { value: '4.8/5', label: 'Note moyenne', icon: '⭐' }
              ].map((stat, index) => (
                <div key={index} className="text-center animate-scale-in" style={{ animationDelay: `${index * 0.2}s` }}>
                  <div className="text-2xl lg:text-3xl font-bold text-road-yellow mb-1">
                    {stat.icon} {stat.value}
                  </div>
                  <div className="text-sm text-blue-200 font-medium">{stat.label}</div>
                </div>
              ))}
            </div>

            {/* Badges de confiance */}
            <div className="flex items-center justify-center space-x-6 pt-6">
              <div className="flex items-center space-x-2 bg-white/10 rounded-full px-4 py-2">
                <Shield className="w-4 h-4 text-green-400" />
                <span className="text-sm font-medium">Paiement sécurisé</span>
              </div>
              <div className="flex items-center space-x-2 bg-white/10 rounded-full px-4 py-2">
                <CheckCircle className="w-4 h-4 text-green-400" />
                <span className="text-sm font-medium">Satisfait ou remboursé</span>
              </div>
            </div>
          </div>

          {/* Visuel avec dashboard mockup */}
          <div className="relative animate-fade-in" style={{ animationDelay: '0.3s' }}>
            <div className="relative z-10">
              <div className="bg-white rounded-3xl shadow-2xl p-8 mx-auto max-w-lg transform hover:scale-105 transition-transform duration-500">
                <div className="space-y-6">
                  {/* Header avec progression */}
                  <div className="flex items-center justify-between">
                    <div className="flex items-center space-x-3">
                      <img 
                        src="/lovable-uploads/19da7ca9-0f9a-4cc2-a914-e68752b9928d.png" 
                        alt="DriveInProgress" 
                        className="w-10 h-10"
                      />
                      <div>
                        <span className="font-bold text-gray-900 text-lg">Jour 3/8</span>
                        <div className="text-sm text-green-600 font-semibold">Signalisation</div>
                      </div>
                    </div>
                    <div className="text-right">
                      <div className="text-sm font-medium text-road-green">75% complété</div>
                      <div className="text-xs text-gray-400">🔥 En avance !</div>
                    </div>
                  </div>

                  {/* Progress bar */}
                  <div className="w-full bg-gray-200 rounded-full h-3 shadow-inner">
                    <div className="bg-gradient-to-r from-road-green to-green-400 h-3 rounded-full shadow-sm" style={{ width: '75%' }}>
                      <div className="h-full bg-white/30 rounded-full"></div>
                    </div>
                  </div>

                  {/* Content avec quiz */}
                  <div className="space-y-4">
                    <h3 className="text-xl font-bold text-gray-900 flex items-center">
                      <span className="text-2xl mr-2">🚸</span>
                      Quiz Signalisation
                    </h3>
                    <div className="bg-blue-50 border border-blue-200 rounded-lg p-4">
                      <p className="text-sm text-blue-800 font-medium mb-2">
                        Question 12/20 : Que signifie ce panneau ?
                      </p>
                      <div className="text-6xl text-center mb-3">🚸</div>
                      <div className="space-y-2">
                        <button className="w-full text-left p-2 bg-green-100 border border-green-300 rounded text-sm">
                          ✅ A. Passage pour piétons
                        </button>
                        <button className="w-full text-left p-2 bg-gray-100 border border-gray-300 rounded text-sm">
                          B. Zone de jeux
                        </button>
                      </div>
                    </div>
                  </div>

                  {/* Stats personnelles */}
                  <div className="grid grid-cols-2 gap-4">
                    <div className="text-center bg-green-50 rounded-lg p-3">
                      <div className="text-lg font-bold text-green-600">18/20</div>
                      <div className="text-xs text-green-700">Score moyen</div>
                    </div>
                    <div className="text-center bg-blue-50 rounded-lg p-3">
                      <div className="text-lg font-bold text-blue-600">5j</div>
                      <div className="text-xs text-blue-700">Restants</div>
                    </div>
                  </div>

                  {/* Action button */}
                  <button className="w-full bg-gradient-to-r from-road-blue to-blue-600 text-white py-4 rounded-xl font-bold text-lg shadow-lg hover:shadow-xl transition-all duration-300 flex items-center justify-center space-x-2">
                    <span>Continuer le quiz</span>
                    <ArrowDown className="w-5 h-5" />
                  </button>
                </div>
              </div>
            </div>

            {/* Éléments décoratifs avec preuves */}
            <div className="absolute -top-6 -right-6 w-32 h-32 bg-gradient-to-br from-green-400 to-green-600 rounded-full opacity-20 animate-pulse-slow flex items-center justify-center">
              <span className="text-white font-bold text-lg">94%</span>
            </div>
            <div className="absolute -bottom-8 -left-8 w-40 h-40 bg-gradient-to-br from-road-yellow to-yellow-400 rounded-full opacity-20 animate-pulse-slow flex items-center justify-center" style={{ animationDelay: '1.5s' }}>
              <span className="text-black font-bold text-lg">12k+</span>
            </div>
          </div>
        </div>
      </div>

      {/* Scroll indicator */}
      <div className="absolute bottom-8 left-1/2 transform -translate-x-1/2 animate-bounce">
        <div className="w-8 h-12 border-2 border-white/50 rounded-full flex justify-center">
          <div className="w-1 h-3 bg-white/70 rounded-full mt-2 animate-pulse"></div>
        </div>
      </div>
    </section>
  );
};

export default Hero;
